@@ -35,10 +35,11 @@ class GitlabEpic:
 
         # get all participants
         pts = [d.extract_participants() for d in self.issues] if self.issues else None
-        participants = [x for y in pts for x in y] if pts else None
+        # if no issues, or no participants use the epic author as participant
+        participants = [x for y in pts for x in y] if pts else [self.epic["author"]]
 
         # update self
-        self.participants = [d for d in participants if d["id"] in list(set([x["id"] for x in participants]))] if self.issues and get_participants else None
+        self.participants = [d for d in participants if d["id"] in list(set([x["id"] for x in participants]))] if self.issues is not None and get_participants else None
 
     def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None) -> list:
         """
