@@ -6,11 +6,13 @@ class GitlabIssue:
     GitlabIssue is a GitLab Issue.
     """
 
-    def __init__(self, id: str = None, issue: dict = None, get_links: bool = False, get_notes: bool = False, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
+    def __init__(self, id: str = None, issue: dict = None, get_links: bool = False, get_notes: bool = False, get_participants: bool = False, token :str = configuration.GITLAB_TOKEN, version: str = configuration.GITLAB_API_VERSION):
         """
         Args:
             id (string): GitLab Issue id
+            get_links (boolean): TRUE if links should be pulled
             get_notes (boolean): TRUE if notes should be pulled
+            get_participants (boolean): TRUE if participants should be pulled
             issue (dict): key/values representing a Gitlab Issue
             token (string): GitLab personal access or deploy token
             version (string): GitLab API version as base url
@@ -26,6 +28,7 @@ class GitlabIssue:
         self.project_id = self.issue["project_id"] if self.issue else None
         self.links = self.extract_links() if get_links else None
         self.notes = self.extract_notes() if get_notes else None
+        self.participants = self.extract_participants() if get_participants else None
 
     def extract_links(self) -> list:
         """
@@ -38,7 +41,7 @@ class GitlabIssue:
         result = None
 
         # check connection params
-        if self.id and self.connection.token and self.connection.version:
+        if self.iid and self.connection.token and self.connection.version:
 
             # query api
             result = self.connection.query(
@@ -61,7 +64,7 @@ class GitlabIssue:
         result = None
 
         # check connection params
-        if self.id and self.connection.token and self.connection.version:
+        if self.iid and self.connection.token and self.connection.version:
 
             # query api
             result = self.connection.paginate(
@@ -72,3 +75,26 @@ class GitlabIssue:
             )
 
         return result
+
+    def extract_participants(self) -> list:
+        """
+        Extract issue-specific participant data.
+
+        Returns:
+            A list of dictionaries where each represents a GitLab User.
+        """
+
+        result = None
+
+        # check connection params
+        if self.iid and self.connection.token and self.connection.version:
+
+            # query api
+            result = self.connection.paginate(
+                endpoint="projects/%s/issues/%s/participants" % (
+                    self.project_id,
+                    self.iid
+                )
+            )
+
+        return result
